package com.io.yutian.aulib.util;

import java.math.BigInteger;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class StringUtil {

	public static byte[] parseByteArray(String string) {
		String[] array = string.split(";");
		byte[] bytes = new byte[array.length];
		for (int i = 0; i < array.length; i++) {
			String s = array[i];
			if (isByte(s)) {
				bytes[i] = Byte.parseByte(s);
			} else {
				return null;
			}
		}
		return bytes;
	}

	public static int[] parseIntArray(String string) {
		String[] array = string.split(";");
		int[] ints = new int[array.length];
		for (int i = 0; i < array.length; i++) {
			String s = array[i];
			if (isInt(s)) {
				ints[i] = Integer.parseInt(s);
			} else {
				return null;
			}
		}
		return ints;
	}
	
	public static List<String> getStringContainData(String str, String start, String end) {
        List<String> result = new ArrayList<>();
        String regex = start + "(.*?)" + end;
        Pattern pattern = Pattern.compile(regex);
        Matcher matcher = pattern.matcher(str);
        while(matcher.find()){
            String key = matcher.group(matcher.groupCount());
            if(!key.contains(start) && !key.contains(end)){
                result.add(key);
            }
        }
        return result;
    }

    public static boolean isByte(String arg0) {
		try {
			Byte.valueOf(arg0);
			return true;
		} catch (Exception e) {
			return false;
		}
	}

	public static boolean isBoolean(String arg0) {
		try {
			if (arg0.equalsIgnoreCase("true") || arg0.equalsIgnoreCase("false")) {
				return true;
			} else {
				return false;
			}
		} catch (Exception e) {
			return false;
		}
	}
	
	public static boolean isDouble(String arg0) {
		try {
			Double.valueOf(arg0);
			return true;
		} catch (Exception e) {
			return false;
		}
	}
	
	public static boolean isFloat(String arg0) {
		try {
			Float.valueOf(arg0);
			return true;
		} catch (Exception e) {
			return false;
		}
	}
	
	public static boolean isInt(String arg0) {
		try {
			Integer.valueOf(arg0);
			return true;
		} catch (Exception e) {
			return false;
		}
	}
	
	public static boolean isLong(String arg0) {
		try {
			Long.valueOf(arg0);
			return true;
		} catch (Exception e) {
			return false;
		}
	}

	public static boolean isEnum(String arg0, Class<? extends Enum> enumType) {
		try {
			Enum.valueOf(enumType, arg0);
			return true;
		} catch (Exception e) {
			return false;
		}
	}

	public static boolean isUUID(String arg0) {
		try {
			UUID.fromString(arg0);
			return true;
		} catch (Exception e) {
			return false;
		}
	}
	
	public static String[] splitSpace(String arg0) {
		return arg0.split(" ");
	}
	
	public static Object getRegexValue(String key, String lore) {
		if (key == null || lore == null) {
			return null;
		}
		String s = lore.contains(":") ? ":" : "：";
		if (lore.contains(s) && lore.contains(key)) {
			Pattern p = Pattern.compile("[^"+key+s+"]+");
			Matcher m = p.matcher(lore);
			try {
				m.find();
				if (m.group() != null) {
					return (Object) m.group();
				}
			} catch (Exception e) {
				return null;
			}
		}
		return null;
	}

	public static UUID getUUIDFromString(String s) {
        String md5 = getMD5(s);
        String uuid = md5.substring(0, 8) + "-" + md5.substring(8, 12) + "-" + md5.substring(12, 16) + "-" + md5.substring(16, 20) + "-" + md5.substring(20);
        
        return UUID.fromString(uuid);
    }
    
    public static String getMD5(String input) {
        try {
            MessageDigest md = MessageDigest.getInstance("MD5");
            byte[] messageDigest = md.digest(input.getBytes());
            BigInteger number = new BigInteger(1, messageDigest);
            String hashtext;
            for (hashtext = number.toString(16); hashtext.length() < 32; hashtext = "0" + hashtext) {}
            return hashtext;
        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException(e);
        }
    }

	public static String convertRGBToHex(int r, int g, int b) {
		String rFString, rSString, gFString, gSString,
				bFString, bSString, result;
		int red, green, blue;
		int rred, rgreen, rblue;
		red = r / 16;
		rred = r % 16;
		if (red == 10) rFString = "A";
		else if (red == 11) rFString = "B";
		else if (red == 12) rFString = "C";
		else if (red == 13) rFString = "D";
		else if (red == 14) rFString = "E";
		else if (red == 15) rFString = "F";
		else rFString = String.valueOf(red);

		if (rred == 10) rSString = "A";
		else if (rred == 11) rSString = "B";
		else if (rred == 12) rSString = "C";
		else if (rred == 13) rSString = "D";
		else if (rred == 14) rSString = "E";
		else if (rred == 15) rSString = "F";
		else rSString = String.valueOf(rred);

		rFString = rFString + rSString;

		green = g / 16;
		rgreen = g % 16;

		if (green == 10) gFString = "A";
		else if (green == 11) gFString = "B";
		else if (green == 12) gFString = "C";
		else if (green == 13) gFString = "D";
		else if (green == 14) gFString = "E";
		else if (green == 15) gFString = "F";
		else gFString = String.valueOf(green);

		if (rgreen == 10) gSString = "A";
		else if (rgreen == 11) gSString = "B";
		else if (rgreen == 12) gSString = "C";
		else if (rgreen == 13) gSString = "D";
		else if (rgreen == 14) gSString = "E";
		else if (rgreen == 15) gSString = "F";
		else gSString = String.valueOf(rgreen);

		gFString = gFString + gSString;

		blue = b / 16;
		rblue = b % 16;

		if (blue == 10) bFString = "A";
		else if (blue == 11) bFString = "B";
		else if (blue == 12) bFString = "C";
		else if (blue == 13) bFString = "D";
		else if (blue == 14) bFString = "E";
		else if (blue == 15) bFString = "F";
		else bFString = String.valueOf(blue);

		if (rblue == 10) bSString = "A";
		else if (rblue == 11) bSString = "B";
		else if (rblue == 12) bSString = "C";
		else if (rblue == 13) bSString = "D";
		else if (rblue == 14) bSString = "E";
		else if (rblue == 15) bSString = "F";
		else bSString = String.valueOf(rblue);
		bFString = bFString + bSString;
		result = "#" + rFString + gFString + bFString;
		return result;

	}

	public static int[] getRGB(String rgb) {
		int[] ret = new int[3];
		for (int i = 0; i < 3; i++) {
			ret[i] = Integer.parseInt(rgb.substring(i * 2, i * 2 + 2), 16);
		}
		return ret;
	}

	private static String[] roman_thousands = {"", "M", "MM", "MMM"};
	private static String[] roman_hundreds  = {"", "C", "CC", "CCC", "CD", "D", "DC", "DCC", "DCCC", "CM"};
	private static String[] roman_tens      = {"", "X", "XX", "XXX", "XL", "L", "LX", "LXX", "LXXX", "XC"};
	private static String[] roman_ones      = {"", "I", "II", "III", "IV", "V", "VI", "VII", "VIII", "IX"};

	public static String intToRoman(int num) {
		StringBuffer roman = new StringBuffer();
		roman.append(roman_thousands[num / 1000]);
		roman.append(roman_hundreds[num % 1000 / 100]);
		roman.append(roman_tens[num % 100 / 10]);
		roman.append(roman_ones[num % 10]);
		return roman.toString();
	}

}
